#include "basictimer.h"

BasicTimer::BasicTimer() :
  m_Box(Gtk::ORIENTATION_HORIZONTAL, 10),
  m_ButtonAddTimer("_Start", true),
  m_ButtonDeleteTimer("_Stop", true),
  m_ButtonQuit("_Quit", true),
  timer_added(false),
  disconnect(false),
  timeout_value(500) // 500 ms = 0.5 seconds
{
  set_border_width(10);

  add(m_Box);
  m_Box.pack_start(m_ButtonAddTimer);
  m_Box.pack_start(m_ButtonDeleteTimer);
  m_Box.pack_start(m_ButtonQuit);

  // Connect the three buttons:
  m_ButtonQuit.signal_clicked().connect(sigc::mem_fun(*this,
              &BasicTimer::on_button_quit));
  m_ButtonAddTimer.signal_clicked().connect(sigc::mem_fun(*this,
              &BasicTimer::on_button_add_timer));
  m_ButtonDeleteTimer.signal_clicked().connect(sigc::mem_fun(*this,
              &BasicTimer::on_button_delete_timer));

  show_all_children();
}

void BasicTimer::on_button_quit()
{
  hide();
}

void BasicTimer::on_button_add_timer()
{
  if(not timer_added)
  {	  
	  Glib::signal_timeout().connect( sigc::mem_fun(*this, &BasicTimer::on_timeout),
									  timeout_value );
		
	  timer_added = true;
	
	  std::cout << "Timer added" << std::endl;
  }
  else
  {
 	  std::cout << "The timer already exists : nothing more is created" << std::endl;
  }
}

void BasicTimer::on_button_delete_timer()
{
  if(not timer_added)
  {
    std::cout << "Sorry, there is no active timer at the moment." << std::endl;
  }
  else
  {
    std::cout << "manually disconnecting the timer " << std::endl;
	disconnect  = true;   
    timer_added = false;
  }
}

bool BasicTimer::on_timeout()
{
  static unsigned int val(1);

  if(disconnect)
  {
	  disconnect = false; // reset for next time a Timer is created
	  
	  return false; // End of Timer 
  }
  
  std::cout << "This is timer value : " << val << std::endl;
  ++val; // tic the clock

  return true; // keep the Timer working
}
